==> minitube-src-0.6.1.tar.gz: minitube/locale/es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_AR" sourcelanguage="en_US">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="../src/AboutView.cpp" line="20"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>¡Hay vida más allá del navegador!</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="21"/>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="24"/>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Esta es una edición &quot;Technology Preview&quot;, no espere que sea perfecta.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="25"/>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Notifique errores y envie sus ideas a %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="28"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 es Software Libre pero su desarrollo supone valioso tiempo.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="29"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;done a través de PayPal&lt;/a&gt; para colaborar con el desarrollo de %2.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="32"/>
        <source>Icon designed by %1.</source>
        <translation>Icono diseñado por %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="34"/>
        <source>Compact mode contributed by %1.</source>
        <translation>Modo compacto aportado por %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="36"/>
        <source>Translated by %1</source>
        <translation>Traducido por %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="46"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Desarrollado bajo la &lt;a href=&apos;%1&apos;&gt;Licencia publica general GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="57"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="18"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="20"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Que es lo que siempre quiso saber acerca de %1 y nunca osó preguntar</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="52"/>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="../src/ListModel.cpp" line="46"/>
        <source>Searching...</source>
        <translation>Buscando...</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="47"/>
        <source>Show %1 More</source>
        <translation>Mostrar %1 más</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="48"/>
        <source>No videos</source>
        <translation>No videos</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="49"/>
        <source>No more videos</source>
        <translation>No más videos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="../src/loadingwidget.cpp" line="64"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="70"/>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Retroceder</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="73"/>
        <source>Go to the previous view</source>
        <translation>Ir a vista previa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="77"/>
        <source>&amp;Stop</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="78"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Detener reproducción y volver a la busqueda</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Escape</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="83"/>
        <source>S&amp;kip</source>
        <translation>&amp;Saltar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="84"/>
        <source>Skip to the next video</source>
        <translation>Saltar al siguiente video</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Avanzar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="90"/>
        <location filename="../src/MainWindow.cpp" line="481"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="91"/>
        <location filename="../src/MainWindow.cpp" line="482"/>
        <source>Pause playback</source>
        <translation>Pausar reproducción</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Espacio</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="97"/>
        <location filename="../src/MainWindow.cpp" line="525"/>
        <source>&amp;Full Screen</source>
        <translation>Pantalla &amp;completa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="98"/>
        <source>Go full screen</source>
        <translation>Ir a pantalla completa</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="123"/>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="124"/>
        <source>Open the YouTube video page</source>
        <translation>Abrir pagina del video en YouTube</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="130"/>
        <source>&amp;Remove</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="131"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Borrar los videos seleccionados de la lista de reproducción</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="137"/>
        <source>Move &amp;Up</source>
        <translation>Mover A&amp;rriba</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="138"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover arriba los videos seleccionados en la lista de reproducción</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Arriba</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="144"/>
        <source>Move &amp;Down</source>
        <translation>Mover Aba&amp;jo</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="145"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover Abajo los videos seleccionados en la lista de reproducción</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Arriba</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="151"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="153"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="154"/>
        <source>Bye</source>
        <translation>Adiós</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="158"/>
        <source>&amp;Website</source>
        <translation>Sitio &amp;web</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube en internet</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="104"/>
        <source>&amp;Compact mode</source>
        <translation>Modo &amp;Compacto</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="105"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ocultar la lista de reproducción y la barra de herramientas</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="160"/>
        <source>%1 on the Web</source>
        <translation>%1 en la Web</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="164"/>
        <source>&amp;Donate via PayPal</source>
        <translation>D&amp;onar a través de PayPal</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="165"/>
        <source>Please support the continued development of %1</source>
        <translation>Por favor sustente el desarrollo continuo de %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="169"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="171"/>
        <source>Info about %1</source>
        <translation>Información de %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Buscar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="179"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="197"/>
        <source>Mute volume</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="198"/>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="235"/>
        <source>&amp;Application</source>
        <translation>&amp;Aplicación</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="241"/>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista de reproducción</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="248"/>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="261"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="297"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Presione %1 para aumentar el volumen, %2 para reducirlo</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="421"/>
        <location filename="../src/MainWindow.cpp" line="427"/>
        <source>Opening %1</source>
        <translation>Abriendo-%1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="472"/>
        <source>Fatal error: %1</source>
        <translation>Error fatal:%1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="474"/>
        <source>Error: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="495"/>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="496"/>
        <source>Resume playback</source>
        <translation>Continuar Reproducción</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="534"/>
        <source>Exit &amp;Full Screen</source>
        <translation>&amp;Salir de pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="627"/>
        <source>Remaining time: %1</source>
        <translation>Tiempo restante: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="664"/>
        <source>Volume at %1%</source>
        <translation>Volumen al %1%</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="669"/>
        <source>Volume is muted</source>
        <translation>Volumen silenciado</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="671"/>
        <source>Volume is unmuted</source>
        <translation>Volumen</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="../src/MediaView.cpp" line="24"/>
        <source>Most relevant</source>
        <translation>Más relevantes</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="31"/>
        <source>Most recent</source>
        <translation>Más recientes</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="38"/>
        <source>Most viewed</source>
        <translation>Más vistos</translation>
    </message>
    <message>
        <location filename="../src/MediaView.h" line="31"/>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Está viendo %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="../src/networkaccess.cpp" line="157"/>
        <source>Network error: %1</source>
        <translation>Error de red: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="142"/>
        <source>%1 views</source>
        <translation>%1-visualizaciones</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="173"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="../src/SearchView.cpp" line="36"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="43"/>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Introduzca una palabra para empezar a ver videos.</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="61"/>
        <source>Watch</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="77"/>
        <source>Recent keywords</source>
        <translation>Búsquedas recientes</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="190"/>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Una nueva versión de %1 esta disponible. Por favor &lt;a href=&apos;%2&apos;&gt;actualice a la version %3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/SearchView.h" line="28"/>
        <source>Make yourself comfortable</source>
        <translation>Personalizar</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <location filename="../src/SettingsView.h" line="17"/>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../src/SettingsView.cpp" line="15"/>
        <source>&amp;Video options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsView.cpp" line="33"/>
        <source>Use high quality video when available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsView.cpp" line="40"/>
        <source>&amp;Saved recent keywords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsView.cpp" line="43"/>
        <source>&amp;Clear recent keywords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SettingsView.cpp" line="47"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="../src/video.cpp" line="102"/>
        <source>Network error: %1 for %2</source>
        <translation>Error de red: %1 por %2</translation>
    </message>
</context>
</TS>

==> minitube-src-0.8.tar.gz: minitube/locale/es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_AR" sourcelanguage="en_US">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>¡Hay vida más allá del navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Esta es una edición &quot;Technology Preview&quot;, no espere que sea perfecta.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Notifique errores y envie sus ideas a %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 es Software Libre pero su desarrollo supone valioso tiempo.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;done a través de PayPal&lt;/a&gt; para colaborar con el desarrollo de %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Icono diseñado por %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Modo compacto contribuido por %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Soporte de proxy HTTP contribuido por %1</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation>Versión Windows compilada por %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Traducido por %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Desarrollado bajo la &lt;a href=&apos;%1&apos;&gt;Licencia publica general GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Que es lo que siempre quiso saber acerca de %1 y nunca osó preguntar</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Buscando...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Mostrar %1 más</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>No videos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>No más videos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="obsolete">Retroceder</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Ir a vista previa</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Detener reproducción y volver a la busqueda</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation type="obsolete">Escape</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Saltar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Saltar al siguiente video</translation>
    </message>
    <message>
        <source>Ctrl+Right</source>
        <translation type="obsolete">Avanzar</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausar reproducción</translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="obsolete">Espacio</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Pantalla &amp;completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir a pantalla completa</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="obsolete">Pantalla completa</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Abrir pagina del video en YouTube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Borrar los videos seleccionados de la lista de reproducción</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover A&amp;rriba</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover arriba los videos seleccionados en la lista de reproducción</translation>
    </message>
    <message>
        <source>Ctrl+Up</source>
        <translation type="obsolete">Arriba</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover Aba&amp;jo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover Abajo los videos seleccionados en la lista de reproducción</translation>
    </message>
    <message>
        <source>Ctrl+Down</source>
        <translation type="obsolete">Arriba</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Adiós</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sitio &amp;web</translation>
    </message>
    <message>
        <source>Minitube on the Web</source>
        <translation type="obsolete">Minitube en internet</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Modo &amp;Compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ocultar la lista de reproducción y la barra de herramientas</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 en la Web</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>D&amp;onar a través de PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor sustente el desarrollo continuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Información de %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">&amp;Buscar</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation type="obsolete">&amp;Aplicación</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista de reproducción</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Presione %1 para aumentar el volumen, %2 para reducirlo</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abriendo-%1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Error fatal:%1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continuar Reproducción</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>&amp;Salir de pantalla completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tiempo restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volumen al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volumen silenciado</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volumen activado</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>Video de alta definición activado</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>Video de alta definición no activado</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>El video actual es de alta definición</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>El video actual no es de alta definición</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Más relevantes</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Más recientes</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Más vistos</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Está viendo %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Error de red: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1-visualizaciones</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Introduzca una palabra para empezar a ver videos.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Búsquedas recientes</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Una nueva versión de %1 esta disponible. Por favor &lt;a href=&apos;%2&apos;&gt;actualice a la version %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Personalizar</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Cerrar</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Error de red: %1 por %2</translation>
    </message>
</context>
</TS>
